package MT::Plugin::IfMatchEntry;
use strict;

use MT;
require MT::Plugin;
use MT::Template::Context;
use MT::Util qw(decode_html);

@MT::Plugin::IfMatchEntry::ISA = qw(MT::Plugin);

my $version = "0.1";
my $description = "Conditional tag if entry contains the text or not.<br />";
$description .= "Example: &lt;MTIfMatchEntry search=&quot;&amp;lt;!--flag--&amp;gt;&quot; item=&quot;excerpt&quot;&gt;";

my $plugin = new MT::Plugin::IfMatchEntry({
	name => 'IfMatchEntry',
	version => $version,
	description => $description,
	author_name => 'Junnama Noda',
	author_link => 'http://junnama.alfasado.net/online/',
});

MT->add_plugin($plugin);

MT::Template::Context->add_conditional_tag(IfMatchEntry => \&_IfMatchEntry);

sub _IfMatchEntry {
	my ($ctx, $args, $cond) = @_;
	my $entry = $ctx->stash('entry') or return $ctx->_no_entry_error('IfMatchEntry');
	my $search = &decode_html($args->{search});
	my $item = $args->{item};
	unless ($item) {
		$item = 'text';
	}
	if ($item =~ /(title|text|text_more|excerpt|keywords|basename)/) {
		if ($entry->$item =~ /$search/) {
			return 1;
		}
	} elsif ($item eq 'all') {
		if (($entry->title =~ /$search/) || ($entry->text =~ /$search/) || ($entry->text_more =~ /$search/) ||
			 ($entry->excerpt =~ /$search/) || ($entry->keywords =~ /$search/) || ($entry->basename =~ /$search/)) {
			return 1;
		}
	}
	return 0;
}

1;